AllureAttachment class

Attachment metadata recorded in an Allure result.

Constructors

AllureAttachment({required String name, required String source, String? type, int? size})
Creates attachment metadata.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
Display name of the attachment.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int?
Attachment size in bytes, when known.
final
source → String
File name of the attachment inside the results directory.
final
type → String?
MIME type of the attachment, when known.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
Converts this attachment to the Allure JSON representation.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited