AllureGlobalAttachment class

Attachment recorded outside an individual test result.

Inheritance

Constructors

AllureGlobalAttachment({required String name, required String source, required int timestamp, String? type, int? size})
Creates global attachment metadata.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Display name of the attachment.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int?
Attachment size in bytes, when known.
finalinherited
source String
File name of the attachment inside the results directory.
finalinherited
timestamp int
Timestamp in milliseconds since epoch when the attachment was recorded.
final
type String?
MIME type of the attachment, when known.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Converts this global attachment to the Allure JSON representation.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited