AllureLabel class

Name/value metadata label attached to an Allure result.

Constructors

AllureLabel({required String name, required String value})
Creates an Allure label.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Label name, such as suite, feature, or tag.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
Label value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, String>
Converts this label to the Allure JSON representation.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited