AllureStepContext class

Context object passed to an active Allure step body.

Constructors

AllureStepContext()
Creates a step context.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

displayName(String name) Future<void>
Overrides the display name of the current step.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parameter(String name, Object? value, {AllureParameterMode? mode}) Future<void>
Adds a parameter to the current step.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited