RuntimeMessage class

Message sent from a test runtime API to an Allure lifecycle sink.

Constructors

RuntimeMessage({required String type, Map<String, Object?> data = const <String, Object?>{}})
Creates a runtime message with a type and optional data payload.
const

Properties

data Map<String, Object?>
Message payload.
final
hashCode int
The hash code for this object.
no setterinherited
isGlobal bool
Whether this message targets run-level data instead of a test context.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
Message type understood by AllureRuntimeMessageSink.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited