AllureConfig class

Configuration loaded from allure-dart.yaml.

Constructors

AllureConfig({String? resultsDirectory, List<AllureLabel> globalLabels = const <AllureLabel>[], AllureEnvironmentInfo environmentInfo = const <String, String?>{}, String? path})
Creates an Allure config value.
const
AllureConfig.load({String? path, String? startDirectory, Map<String, String>? environment})
Loads an Allure config file.
factory

Properties

environmentInfo AllureEnvironmentInfo
Run-level environment information written to environment.properties.
final
globalLabels List<AllureLabel>
Labels added to every written test result.
final
hashCode int
The hash code for this object.
no setterinherited
path String?
Path of the config file that produced this value, when loaded from disk.
final
resultsDirectory String?
Results output directory from resultsDir or resultsDirectory.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

empty → const AllureConfig
Empty configuration that disables auto-loaded values when passed explicitly to APIs accepting AllureConfig.