AllureFixtureResult class
Allure fixture result used for setup and teardown records.
- Inheritance
-
- Object
- AllureExecutable
- AllureFixtureResult
Constructors
-
AllureFixtureResult({String? name, AllureStatus? status = AllureStatus.broken, AllureStatusDetails statusDetails = const AllureStatusDetails(), AllureStage stage = AllureStage.pending, String? description, String? descriptionHtml, List<
AllureStepResult> ? steps, List<AllureAttachment> ? attachments, List<AllureParameter> ? parameters, int? start, int? stop}) - Creates a fixture result.
Properties
-
attachments
→ List<
AllureAttachment> -
Attachments associated with this executable item.
finalinherited
- description ↔ String?
-
Markdown description.
getter/setter pairinherited
- descriptionHtml ↔ String?
-
HTML description.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String?
-
Display name of the executable item.
getter/setter pairinherited
-
parameters
→ List<
AllureParameter> -
Parameters associated with this executable item.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stage ↔ AllureStage
-
Current lifecycle stage.
getter/setter pairinherited
- start ↔ int?
-
Start timestamp in milliseconds since epoch.
getter/setter pairinherited
- status ↔ AllureStatus?
-
Final status of the executable item.
getter/setter pairinherited
- statusDetails ↔ AllureStatusDetails
-
Detailed status information.
getter/setter pairinherited
-
steps
→ List<
AllureStepResult> -
Child steps nested under this executable item.
finalinherited
- stop ↔ int?
-
Stop timestamp in milliseconds since epoch.
getter/setter pairinherited
Methods
-
executableToJson(
) → Map< String, Object?> -
Converts shared executable fields to an Allure JSON map.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Converts this fixture to the Allure JSON representation.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited