AllureTestResultContainer class
Allure container result written as a *-container.json file.
Constructors
-
AllureTestResultContainer({required String uuid, String? name, String? description, String? descriptionHtml, List<
String> ? children, List<AllureFixtureResult> ? befores, List<AllureFixtureResult> ? afters, List<AllureLink> ? links, int? start, int? stop}) - Creates a test result container.
Properties
-
afters
→ List<
AllureFixtureResult> -
Teardown fixture results.
final
-
befores
→ List<
AllureFixtureResult> -
Setup fixture results.
final
-
children
→ List<
String> -
Child test result UUIDs in this container.
final
- description ↔ String?
-
Markdown description for the container.
getter/setter pair
- descriptionHtml ↔ String?
-
HTML description for the container.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
links
→ List<
AllureLink> -
Links attached to the container.
final
- name ↔ String?
-
Optional display name of the container.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start ↔ int?
-
Start timestamp in milliseconds since epoch.
getter/setter pair
- stop ↔ int?
-
Stop timestamp in milliseconds since epoch.
getter/setter pair
- uuid → String
-
Unique identifier of the container.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Converts this container to the Allure JSON representation.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited